@@ -844,3 +844,9 @@
 ( cd usr/man/mann ; ln -sf auto_execok.n.gz auto_load.n.gz )
 ( cd usr/man/mann ; rm -rf tcl_wordBreakAfter.n.gz )
 ( cd usr/man/mann ; ln -sf auto_execok.n.gz tcl_wordBreakAfter.n.gz )
+( cd usr/include/tcl-private/generic ; rm -rf tcl.h )
+( cd usr/include/tcl-private/generic ; ln -sf ../../tcl.h tcl.h )
+( cd usr/include/tcl-private/generic ; rm -rf tclPlatDecls.h )
+( cd usr/include/tcl-private/generic ; ln -sf ../../tclPlatDecls.h tclPlatDecls.h )
+( cd usr/include/tcl-private/generic ; rm -rf tclDecls.h )
+( cd usr/include/tcl-private/generic ; ln -sf ../../tclDecls.h tclDecls.h )
